==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/iot/kotlin/inputs/TopicRuleErrorActionDynamodbArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.iot.kotlin.inputs

import com.pulumi.aws.iot.inputs.TopicRuleErrorActionDynamodbArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property hashKeyField The hash key name.
 * @property hashKeyType The hash key type. Valid values are "STRING" or "NUMBER".
 * @property hashKeyValue The hash key value.
 * @property operation The operation. Valid values are "INSERT", "UPDATE", or "DELETE".
 * @property payloadField The action payload.
 * @property rangeKeyField The range key name.
 * @property rangeKeyType The range key type. Valid values are "STRING" or "NUMBER".
 * @property rangeKeyValue The range key value.
 * @property roleArn The ARN of the IAM role that grants access to the DynamoDB table.
 * @property tableName The name of the DynamoDB table.
 */
public data class TopicRuleErrorActionDynamodbArgs(
    public val hashKeyField: Output<String>,
    public val hashKeyType: Output<String>? = null,
    public val hashKeyValue: Output<String>,
    public val operation: Output<String>? = null,
    public val payloadField: Output<String>? = null,
    public val rangeKeyField: Output<String>? = null,
    public val rangeKeyType: Output<String>? = null,
    public val rangeKeyValue: Output<String>? = null,
    public val roleArn: Output<String>,
    public val tableName: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.iot.inputs.TopicRuleErrorActionDynamodbArgs> {
    override fun toJava(): com.pulumi.aws.iot.inputs.TopicRuleErrorActionDynamodbArgs =
        com.pulumi.aws.iot.inputs.TopicRuleErrorActionDynamodbArgs.builder()
            .hashKeyField(hashKeyField.applyValue({ args0 -> args0 }))
            .hashKeyType(hashKeyType?.applyValue({ args0 -> args0 }))
            .hashKeyValue(hashKeyValue.applyValue({ args0 -> args0 }))
            .operation(operation?.applyValue({ args0 -> args0 }))
            .payloadField(payloadField?.applyValue({ args0 -> args0 }))
            .rangeKeyField(rangeKeyField?.applyValue({ args0 -> args0 }))
            .rangeKeyType(rangeKeyType?.applyValue({ args0 -> args0 }))
            .rangeKeyValue(rangeKeyValue?.applyValue({ args0 -> args0 }))
            .roleArn(roleArn.applyValue({ args0 -> args0 }))
            .tableName(tableName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TopicRuleErrorActionDynamodbArgs].
 */
@PulumiTagMarker
public class TopicRuleErrorActionDynamodbArgsBuilder internal constructor() {
    private var hashKeyField: Output<String>? = null

    private var hashKeyType: Output<String>? = null

    private var hashKeyValue: Output<String>? = null

    private var operation: Output<String>? = null

    private var payloadField: Output<String>? = null

    private var rangeKeyField: Output<String>? = null

    private var rangeKeyType: Output<String>? = null

    private var rangeKeyValue: Output<String>? = null

    private var roleArn: Output<String>? = null

    private var tableName: Output<String>? = null

    /**
     * @param value The hash key name.
     */
    @JvmName("ygcoaywsvtiwwcuk")
    public suspend fun hashKeyField(`value`: Output<String>) {
        this.hashKeyField = value
    }

    /**
     * @param value The hash key type. Valid values are "STRING" or "NUMBER".
     */
    @JvmName("cxekcahknextnmab")
    public suspend fun hashKeyType(`value`: Output<String>) {
        this.hashKeyType = value
    }

    /**
     * @param value The hash key value.
     */
    @JvmName("vlvlypgbspyfnngb")
    public suspend fun hashKeyValue(`value`: Output<String>) {
        this.hashKeyValue = value
    }

    /**
     * @param value The operation. Valid values are "INSERT", "UPDATE", or "DELETE".
     */
    @JvmName("wrmebpvojugqysbs")
    public suspend fun operation(`value`: Output<String>) {
        this.operation = value
    }

    /**
     * @param value The action payload.
     */
    @JvmName("mqeiaoyfwtepktde")
    public suspend fun payloadField(`value`: Output<String>) {
        this.payloadField = value
    }

    /**
     * @param value The range key name.
     */
    @JvmName("bqtkshrvkuuwjjkd")
    public suspend fun rangeKeyField(`value`: Output<String>) {
        this.rangeKeyField = value
    }

    /**
     * @param value The range key type. Valid values are "STRING" or "NUMBER".
     */
    @JvmName("ednuyjtbevkayagl")
    public suspend fun rangeKeyType(`value`: Output<String>) {
        this.rangeKeyType = value
    }

    /**
     * @param value The range key value.
     */
    @JvmName("oxsdixmhetxnslkd")
    public suspend fun rangeKeyValue(`value`: Output<String>) {
        this.rangeKeyValue = value
    }

    /**
     * @param value The ARN of the IAM role that grants access to the DynamoDB table.
     */
    @JvmName("wjqxvtplkycsbevk")
    public suspend fun roleArn(`value`: Output<String>) {
        this.roleArn = value
    }

    /**
     * @param value The name of the DynamoDB table.
     */
    @JvmName("wtcxodauqtvntkwy")
    public suspend fun tableName(`value`: Output<String>) {
        this.tableName = value
    }

    /**
     * @param value The hash key name.
     */
    @JvmName("bmooddckxumvcxbr")
    public suspend fun hashKeyField(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hashKeyField = mapped
    }

    /**
     * @param value The hash key type. Valid values are "STRING" or "NUMBER".
     */
    @JvmName("dkqhcvyeuufbbhsq")
    public suspend fun hashKeyType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hashKeyType = mapped
    }

    /**
     * @param value The hash key value.
     */
    @JvmName("iqghstprgentrsnc")
    public suspend fun hashKeyValue(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hashKeyValue = mapped
    }

    /**
     * @param value The operation. Valid values are "INSERT", "UPDATE", or "DELETE".
     */
    @JvmName("inmaigsqstuksjlp")
    public suspend fun operation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.operation = mapped
    }

    /**
     * @param value The action payload.
     */
    @JvmName("tdinumsqvvnqbufs")
    public suspend fun payloadField(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.payloadField = mapped
    }

    /**
     * @param value The range key name.
     */
    @JvmName("nwwofbrhoeoxayfe")
    public suspend fun rangeKeyField(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rangeKeyField = mapped
    }

    /**
     * @param value The range key type. Valid values are "STRING" or "NUMBER".
     */
    @JvmName("tiorbhjcdicluete")
    public suspend fun rangeKeyType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rangeKeyType = mapped
    }

    /**
     * @param value The range key value.
     */
    @JvmName("laqlwgcgabmxsdca")
    public suspend fun rangeKeyValue(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rangeKeyValue = mapped
    }

    /**
     * @param value The ARN of the IAM role that grants access to the DynamoDB table.
     */
    @JvmName("ntoowvyotjgopgud")
    public suspend fun roleArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roleArn = mapped
    }

    /**
     * @param value The name of the DynamoDB table.
     */
    @JvmName("casvtcpdkyoxkmpq")
    public suspend fun tableName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tableName = mapped
    }

    internal fun build(): TopicRuleErrorActionDynamodbArgs = TopicRuleErrorActionDynamodbArgs(
        hashKeyField = hashKeyField ?: throw PulumiNullFieldException("hashKeyField"),
        hashKeyType = hashKeyType,
        hashKeyValue = hashKeyValue ?: throw PulumiNullFieldException("hashKeyValue"),
        operation = operation,
        payloadField = payloadField,
        rangeKeyField = rangeKeyField,
        rangeKeyType = rangeKeyType,
        rangeKeyValue = rangeKeyValue,
        roleArn = roleArn ?: throw PulumiNullFieldException("roleArn"),
        tableName = tableName ?: throw PulumiNullFieldException("tableName"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/iot/kotlin/inputs/TopicRuleErrorActionDynamodbArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.iot.kotlin.inputs

import com.pulumi.aws.iot.inputs.TopicRuleErrorActionDynamodbArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property hashKeyField The hash key name.
 * @property hashKeyType The hash key type. Valid values are "STRING" or "NUMBER".
 * @property hashKeyValue The hash key value.
 * @property operation The operation. Valid values are "INSERT", "UPDATE", or "DELETE".
 * @property payloadField The action payload.
 * @property rangeKeyField The range key name.
 * @property rangeKeyType The range key type. Valid values are "STRING" or "NUMBER".
 * @property rangeKeyValue The range key value.
 * @property roleArn The ARN of the IAM role that grants access to the DynamoDB table.
 * @property tableName The name of the DynamoDB table.
 */
public data class TopicRuleErrorActionDynamodbArgs(
    public val hashKeyField: Output<String>,
    public val hashKeyType: Output<String>? = null,
    public val hashKeyValue: Output<String>,
    public val operation: Output<String>? = null,
    public val payloadField: Output<String>? = null,
    public val rangeKeyField: Output<String>? = null,
    public val rangeKeyType: Output<String>? = null,
    public val rangeKeyValue: Output<String>? = null,
    public val roleArn: Output<String>,
    public val tableName: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.iot.inputs.TopicRuleErrorActionDynamodbArgs> {
    override fun toJava(): com.pulumi.aws.iot.inputs.TopicRuleErrorActionDynamodbArgs =
        com.pulumi.aws.iot.inputs.TopicRuleErrorActionDynamodbArgs.builder()
            .hashKeyField(hashKeyField.applyValue({ args0 -> args0 }))
            .hashKeyType(hashKeyType?.applyValue({ args0 -> args0 }))
            .hashKeyValue(hashKeyValue.applyValue({ args0 -> args0 }))
            .operation(operation?.applyValue({ args0 -> args0 }))
            .payloadField(payloadField?.applyValue({ args0 -> args0 }))
            .rangeKeyField(rangeKeyField?.applyValue({ args0 -> args0 }))
            .rangeKeyType(rangeKeyType?.applyValue({ args0 -> args0 }))
            .rangeKeyValue(rangeKeyValue?.applyValue({ args0 -> args0 }))
            .roleArn(roleArn.applyValue({ args0 -> args0 }))
            .tableName(tableName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TopicRuleErrorActionDynamodbArgs].
 */
@PulumiTagMarker
public class TopicRuleErrorActionDynamodbArgsBuilder internal constructor() {
    private var hashKeyField: Output<String>? = null

    private var hashKeyType: Output<String>? = null

    private var hashKeyValue: Output<String>? = null

    private var operation: Output<String>? = null

    private var payloadField: Output<String>? = null

    private var rangeKeyField: Output<String>? = null

    private var rangeKeyType: Output<String>? = null

    private var rangeKeyValue: Output<String>? = null

    private var roleArn: Output<String>? = null

    private var tableName: Output<String>? = null

    /**
     * @param value The hash key name.
     */
    @JvmName("sghrjcvpdrfqxlrm")
    public suspend fun hashKeyField(`value`: Output<String>) {
        this.hashKeyField = value
    }

    /**
     * @param value The hash key type. Valid values are "STRING" or "NUMBER".
     */
    @JvmName("movfeloqommelees")
    public suspend fun hashKeyType(`value`: Output<String>) {
        this.hashKeyType = value
    }

    /**
     * @param value The hash key value.
     */
    @JvmName("vocxioxrbcoibnny")
    public suspend fun hashKeyValue(`value`: Output<String>) {
        this.hashKeyValue = value
    }

    /**
     * @param value The operation. Valid values are "INSERT", "UPDATE", or "DELETE".
     */
    @JvmName("fymrpfkebmnsftdm")
    public suspend fun operation(`value`: Output<String>) {
        this.operation = value
    }

    /**
     * @param value The action payload.
     */
    @JvmName("qipraapiqwfurqnq")
    public suspend fun payloadField(`value`: Output<String>) {
        this.payloadField = value
    }

    /**
     * @param value The range key name.
     */
    @JvmName("hnmchppkwwtrkyrc")
    public suspend fun rangeKeyField(`value`: Output<String>) {
        this.rangeKeyField = value
    }

    /**
     * @param value The range key type. Valid values are "STRING" or "NUMBER".
     */
    @JvmName("dgabpdkivfjjclif")
    public suspend fun rangeKeyType(`value`: Output<String>) {
        this.rangeKeyType = value
    }

    /**
     * @param value The range key value.
     */
    @JvmName("eytkydbmcutrupuu")
    public suspend fun rangeKeyValue(`value`: Output<String>) {
        this.rangeKeyValue = value
    }

    /**
     * @param value The ARN of the IAM role that grants access to the DynamoDB table.
     */
    @JvmName("otdcgblvucbsjifl")
    public suspend fun roleArn(`value`: Output<String>) {
        this.roleArn = value
    }

    /**
     * @param value The name of the DynamoDB table.
     */
    @JvmName("urfhpbvtixorspuk")
    public suspend fun tableName(`value`: Output<String>) {
        this.tableName = value
    }

    /**
     * @param value The hash key name.
     */
    @JvmName("fuiguncwnfadbtjc")
    public suspend fun hashKeyField(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hashKeyField = mapped
    }

    /**
     * @param value The hash key type. Valid values are "STRING" or "NUMBER".
     */
    @JvmName("umcbehjgskvvskak")
    public suspend fun hashKeyType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hashKeyType = mapped
    }

    /**
     * @param value The hash key value.
     */
    @JvmName("qprivlddtjeullji")
    public suspend fun hashKeyValue(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hashKeyValue = mapped
    }

    /**
     * @param value The operation. Valid values are "INSERT", "UPDATE", or "DELETE".
     */
    @JvmName("cjrleekeguoopawj")
    public suspend fun operation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.operation = mapped
    }

    /**
     * @param value The action payload.
     */
    @JvmName("ixmfsfrstpqonjfh")
    public suspend fun payloadField(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.payloadField = mapped
    }

    /**
     * @param value The range key name.
     */
    @JvmName("oigbriydnivqoywi")
    public suspend fun rangeKeyField(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rangeKeyField = mapped
    }

    /**
     * @param value The range key type. Valid values are "STRING" or "NUMBER".
     */
    @JvmName("pkpmybswjgvhqies")
    public suspend fun rangeKeyType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rangeKeyType = mapped
    }

    /**
     * @param value The range key value.
     */
    @JvmName("jqmdplfoogjsdlxe")
    public suspend fun rangeKeyValue(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rangeKeyValue = mapped
    }

    /**
     * @param value The ARN of the IAM role that grants access to the DynamoDB table.
     */
    @JvmName("cbiswuutdjcywsmu")
    public suspend fun roleArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roleArn = mapped
    }

    /**
     * @param value The name of the DynamoDB table.
     */
    @JvmName("mmohdcggcfhkjlwo")
    public suspend fun tableName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tableName = mapped
    }

    internal fun build(): TopicRuleErrorActionDynamodbArgs = TopicRuleErrorActionDynamodbArgs(
        hashKeyField = hashKeyField ?: throw PulumiNullFieldException("hashKeyField"),
        hashKeyType = hashKeyType,
        hashKeyValue = hashKeyValue ?: throw PulumiNullFieldException("hashKeyValue"),
        operation = operation,
        payloadField = payloadField,
        rangeKeyField = rangeKeyField,
        rangeKeyType = rangeKeyType,
        rangeKeyValue = rangeKeyValue,
        roleArn = roleArn ?: throw PulumiNullFieldException("roleArn"),
        tableName = tableName ?: throw PulumiNullFieldException("tableName"),
    )
}
